@@ -1,15 +1,14 @@
 # -*- coding: utf-8 -*-
 """
-    # Shake-Auth
+# Shake-Auth
 
-    Shake's awesome authentication extension.
-    
-    
-    --------
-    Copyright © 2010–2011 by Lúcuma labs (http://lucumalabs.com).
+Shake's awesome authentication extension.
 
-    MIT License. (http://www.opensource.org/licenses/mit-license.php)
-    
+
+---------------------------------------
+Copyright © 2011 by [Lúcuma labs] (http://lucumalabs.com).  
+See `AUTHORS.md` for more details.  
+License: [MIT License] (http://www.opensource.org/licenses/mit-license.php).    
 """
 from .auth import (Auth, CREDENTIAL_LOGIN, CREDENTIAL_PASSWORD,
     CREDENTIAL_TOKEN, UserExistsError, UserDoesNotExistsError,
@@ -17,4 +16,4 @@ from .auth import (Auth, CREDENTIAL_LOGIN, CREDENTIAL_PASSWORD,
 from .perms import protected, is_valid, invalid_csrf_secret
 from .utils import get_user_model, LazyUser, Token
 
-__version__ = '0.9'
\ No newline at end of file
+__version__ = '0.10'
\ No newline at end of file
