@@ -16,7 +16,7 @@ import time
 from shake import url_for, from36, to36, redirect, Rule, StorageDict
 
 try:
-    import shake_mail
+    import mailshake
 except ImportError:
     pass
 
@@ -289,8 +289,8 @@ class Auth(object):
                 ])
         
         if self.settings.password_reset:
-            assert 'shake_mail' in globals().keys(), ('You need the '
-                '`shake_mail`  extension to use the password reset views.')
+            assert 'mailshake' in globals().keys(), ('You need the '
+                '`Mailshake` module to use the password reset views.')
             assert self.settings.mailer, ('You need provide a `mailer` '
                 'parameter to use the password reset views.')
             
@@ -578,13 +578,18 @@ class Auth(object):
         msg = msg.encode('utf-8')
         
         mailer = self.settings.mailer
-        message = mail.Message(
-            From=mailer.default_from,
-            To=user.email,
-            Subject='Reset your password',
-            Html=msg,
-            )
-        mailer.send(message)
+        email_msg = mailshake.EmailMessage(
+            subject='Reset your password',
+            text_content='',
+            from_email=mailer.default_from,
+            to=user.email
+        )
+        if view.endswith('.html'):
+            email_msg.html_content = msg
+        else:
+            email_msg.text_content = msg
+
+        mailer.send(email_msg)
     
     def change_password_view(self, request, user_requested=True, **kwargs):
         """A view to change your password.
