@@ -20,8 +20,6 @@ import os
 from jinja2 import PackageLoader
 from shake import url_for
 
-
-AUTH_SESSION_NAME = '_uhm'
 DEFAULT_HASH_COST = 10
 
 auth_loader = PackageLoader('shake_auth', 'views')
@@ -34,6 +32,8 @@ class LazyUser(object):
     password *salt*. That way, an admin or the user herself can invalidate
     the login in other computers just by changing (or re-saving) her password.
     """
+
+    SESSION_NAME = '_uhm'
     
     def __init__(self, db, User):
         self.db = db
@@ -41,26 +41,36 @@ class LazyUser(object):
     
     def __get__(self, request, obj_type=None):
         user = None
-        uhmac = request.session.get(AUTH_SESSION_NAME)
+        uhmac = request.session.get(self.SESSION_NAME)
         if uhmac:
             try:
                 uid, mac = uhmac.split('$')
                 user = self.db.query(self.User).get(uid)
-                if not user or uhmac != get_user_hmac(user):
+                if not user or uhmac != self.get_user_hmac(user):
                     raise ValueError
             except ValueError:
                 user = None
                 request.session.invalidate()
         request.user = user
         return user
-
-
-def get_user_hmac(user):
-    # This use as a seed a few chars from the password SALT.
-    # NOT from the real password.
-    mac = hashlib.sha256(user.password[10:18])
-    mac = mac.hexdigest()[:8]
-    return '%s$%s' % (user.id, mac)
+    
+    @classmethod
+    def get_user_hmac(cls, user):
+        # This use as a seed a few chars from the password SALT.
+        # NOT from the real password.
+        mac = hashlib.sha256(user.password[10:18])
+        mac = mac.hexdigest()[:8]
+        return '%s$%s' % (user.id, mac)
+    
+    @classmethod
+    def sign_in(cls, request, user):
+        request.session[cls.SESSION_NAME] = cls.get_user_hmac(user)
+        request.user = user
+    
+    @classmethod
+    def sign_out(cls, request):
+        request.session.invalidate()
+        request.user = None
 
 
 class Token(object):
